@@ -41,37 +41,54 @@ sub get_sql_type {
     $self->sql_types->{ $column_name };
 }
 
-sub get_deflator { $_[0]->{deflators}->{$_[1]} }
-sub get_inflator { $_[0]->{inflators}->{$_[1]} }
-sub set_deflator {
-    my ($self, $col, $code) = @_;
-
+sub add_deflator {
+    my ($self, $rule, $code) = @_;
+    if ( ref $rule ne 'Regexp' ) {
+        $rule = qr/^\Q$rule\E$/;
+    }
     unless (ref($code) eq 'CODE') {
         Carp::croak('deflate code must be coderef.');
     }
-    $self->{deflators}->{$col} = $code;
+    push @{ $self->{deflators} }, ( $rule, $code );
 }
-sub set_inflator {
-    my ($self, $col, $code) = @_;
 
-    unless (ref($code) eq 'CODE') {
-        Carp::croak('deflate code must be coderef.');
+sub add_inflator {
+    my ($self, $rule, $code) = @_;
+    if ( ref $rule ne 'Regexp' ) {
+        $rule = qr/^\Q$rule\E$/;
     }
-    $self->{inflators}->{$col} = $code;
+    unless (ref($code) eq 'CODE') {
+        Carp::croak('inflate code must be coderef.');
+    }
+    push @{ $self->{inflators} }, ( $rule, $code );
 }
 
 sub call_deflate {
     my ($self, $col_name, $col_value) = @_;
-    if (my $code = $self->get_deflator( $col_name )) {
-        return $code->($col_value);
+    my $rules = $self->{deflators};
+    my $i = 0;
+    my $max = @$rules;
+    while ( $i < $max ) {
+        my ($rule, $code) = @$rules[ $i, $i + 1 ];
+        if ($col_name =~ /$rule/) {
+            return $code->($col_value);
+        }
+        $i += 2;
     }
     return $col_value;
 }
 
 sub call_inflate {
     my ($self, $col_name, $col_value) = @_;
-    if (my $code = $self->get_inflator( $col_name )) {
-        return $code->($col_value);
+    my $rules = $self->{inflators};
+    my $i = 0;
+    my $max = @$rules;
+    while ( $i < $max ) {
+        my ($rule, $code) = @$rules[ $i, $i + 1 ];
+        if ($col_name =~ /$rule/) {
+            return $code->($col_value);
+        }
+        $i += 2;
     }
     return $col_value;
 }
